Summary: Tool for managing bootable, immutable filesystem trees
Name: ostree
Version: 2015.6
Release: 2.atomic%{?dist}.2
#VCS: git:git://git.gnome.org/ostree
Source0: http://ftp.gnome.org/pub/GNOME/sources/ostree/%{version}/ostree-%{version}.tar.xz
Source1: 91-ostree.preset
### CentOS specific patches
# We carry this one as it's a critical bug in upstream
Patch0: sysroot-sort-returned-bootloader-configs.patch
# This one is necessary - also a bug in upstream that
# we hit but upstream didn't because they haven't rebuilt anaconda
# with a newer ostree
Patch1: 0001-sysroot-Close-sysroot-fd-in-finalize.patch
###
License: LGPLv2+
URL: http://live.gnome.org/OSTree

# For autosetup
BuildRequires: git
# We always run autogen.sh
BuildRequires: autoconf automake libtool
# For docs
BuildRequires: gtk-doc
# Core requirements
BuildRequires: pkgconfig(libgsystem) >= 2015.1
BuildRequires: pkgconfig(libsoup-2.4)
BuildRequires: libattr-devel
# Extras
BuildRequires: pkgconfig(libarchive)
BuildRequires: pkgconfig(libselinux)
BuildRequires: pkgconfig(liblzma)
BuildRequires: pkgconfig(e2p)
BuildRequires: libcap-devel
BuildRequires: gpgme-devel
BuildRequires: pkgconfig(systemd)
BuildRequires: /usr/bin/g-ir-scanner
BuildRequires: dracut

# Runtime requirements
Requires: libgsystem >= 2015.1
Requires: dracut
Requires: systemd-units

%description
OSTree is a tool for managing bootable, immutable, versioned
filesystem trees. While it takes over some of the roles of tradtional
"package managers" like dpkg and rpm, it is not a package system; nor
is it a tool for managing full disk images. Instead, it sits between
those levels, offering a blend of the advantages (and disadvantages)
of both.

%package devel
Summary: Development headers for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
The %{name}-devel package includes the header files for the %{name} library.

%package grub2
Summary: GRUB2 integration for OSTree
Group: Development/Libraries
Requires: grub2

%description grub2
GRUB2 integration for OSTree

%prep
%autosetup -n ostree-%{version} -Sgit

%build
env NOCONFIGURE=1 ./autogen.sh
%configure --disable-silent-rules \
	   --enable-gtk-doc \
	   --disable-static-deltas \
	   --with-selinux \
	   --enable-libsoup-client-certs \
	   --with-dracut
make %{?_smp_mflags}

%install
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p -c"
find $RPM_BUILD_ROOT -name '*.la' -delete
install -D -m 0644 %{SOURCE1} $RPM_BUILD_ROOT/%{_prefix}/lib/systemd/system-preset/91-ostree.preset

%clean
rm -rf $RPM_BUILD_ROOT

%post
%systemd_post ostree-remount.service

%preun
%systemd_preun ostree-remount.service

%files
%doc COPYING README.md
%{_bindir}/ostree
%{_sbindir}/ostree-prepare-root
%{_sbindir}/ostree-remount
%{_datadir}/ostree/trusted.gpg.d
%{_sysconfdir}/ostree
%{_sysconfdir}/dracut.conf.d/ostree.conf
%dir %{_prefix}/lib/dracut/modules.d/98ostree
%{_prefix}/lib/systemd/system/ostree*.service
%{_prefix}/lib/dracut/modules.d/98ostree/*
%{_libdir}/*.so.1*
%{_libdir}/girepository-1.0/OSTree-1.0.typelib
%{_mandir}/man*/*.gz
%{_prefix}/lib/systemd/system-preset/91-ostree.preset

%files devel
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*
%dir %{_datadir}/gtk-doc/html/ostree
%{_datadir}/gtk-doc/html/ostree
%{_datadir}/gir-1.0/OSTree-1.0.gir

%files grub2
%{_sysconfdir}/grub.d/*ostree
%{_libexecdir}/ostree/grub2*

%changelog
* Fri Apr 17 2015 Colin Walters <walters@redhat.com> - 2015.6-2.atomic
- New upstream release

* Tue Apr 07 2015 Colin Walters <walters@redhat.com> - 2015.5-2.atomic
- New upstream release

* Fri Jan 23 2015 Colin Walters <walters@redhat.com> - 2015.3-2.atomic
- New upstream release
- Disable static deltas until they are stable

* Thu Jan 08 2015 Colin Walters <walters@redhat.com> - 2015.2-1.atomic
- New upstream release

* Fri Dec 19 2014 Colin Walters <walters@redhat.com> - 2014.9-4.atomic
- Rebuild for 7.1

* Mon Oct 27 2014 Colin Walters <walters@redhat.com> - 2014.9-3.atomic
- Add patch to fix crasher on UEFI

* Fri Oct 24 2014 Colin Walters <walters@redhat.com> - 2014.9-2.atomic
- New upstream release

* Fri Oct 17 2014 Colin Walters <walters@redhat.com> - 2014.8-2.atomic
- Add patch for anaconda work

* Thu Oct 16 2014 Colin Walters <walters@redhat.com> - 2014.8-1.atomic
- New upstream source

* Fri Oct 03 2014 Colin Walters <walters@redhat.com> - 2014.7-1.atomic
- New upstream source

* Sat Sep 20 2014 Colin Walters <walters@redhat.com> - 2014.6-3.atomic
- Backport patches for /etc merging

* Mon Sep 08 2014 Colin Walters <walters@redhat.com> - 2014.6-2.atomic
- New upstream release

* Fri Jun 27 2014 Colin Walters <walters@redhat.com>
- Add patch for tls-ca-path to enable restricting to Red Hat CDN CA

* Thu Jun 26 2014 Colin Walters <walters@redhat.com>
- Add patch to hard require client certs, use it.  This ensures
  that the functionality is available in the buildroot, and we
  do not silently compile without it.

* Thu Jun 26 2014 Colin Walters <walters@redhat.com>
- Rebuild to pick up tagged libsoup for client-side certs

* Thu Jun 12 2014 Colin Walters <walters@redhat.com>
- New atomic build

* Sat Mar 22 2014 Colin Walters <walters@verbum.org> - 2014.3-1.collider.0
- New upstream release

* Sat Mar 01 2014 Colin Walters <walters@verbum.org> - 2014.2-1
- New upstream release
- Depend on libselinux
- Explicitly depend on libarchive too, we were actually failing
  to disable it before

* Fri Jan 24 2014 Colin Walters <walters@verbum.org> - 2014.1-1
- New upstream release

* Mon Jan 13 2014 Colin Walters <walters@verbum.org> - 2013.7-2
- Add preset file so ostree-remount is enabled by default, since
  it needs to be.

* Tue Oct 15 2013 Colin Walters <walters@verbum.org> - 2013.7-1
- New upstream release
- Now LGPLv2+ only
- Enable libarchive since it might be useful for people
- Enable new gpgme dependency

* Thu Sep 12 2013 Colin Walters <walters@verbum.org> - 2013.6-3
- Enable introspection

* Mon Sep 09 2013 Colin Walters <walters@verbum.org> - 2013.6-2
- Tweak description

* Mon Sep 09 2013 Colin Walters <walters@verbum.org> - 2013.6-1
- New upstream release

* Sat Aug 25 2013 Colin Walters <walters@verbum.org> - 2013.5-3
- And actually while we are here, drop all the embedded dependency
  goop from this spec file; it may live on in the EPEL branch.

* Sat Aug 25 2013 Colin Walters <walters@verbum.org> - 2013.5-2
- Drop requirement on linux-user-chroot
  We now require triggers to be processed on the build server
  by default, so ostree does not runtime-depend on linux-user-chroot.

* Sat Aug 17 2013 Colin Walters <walters@verbum.org> - 2013.5-1
- New upstream release
- Add devel package

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2013.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 16 2013 Colin Walters <walters@verbum.org> - 2013.4-1
- New upstream release

* Sun Jul 07 2013 Colin Walters <walters@verbum.org> - 2013.3-1
- New upstream release

* Mon Apr 01 2013 Colin Walters <walters@verbum.org> - 2013.1-1
- New upstream release

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2012.13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sun Dec 23 2012 Colin Walters <walters@verbum.org> - 2012.13-1
- New upstream release

* Tue Dec 18 2012 Colin Walters <walters@verbum.org> - 2012.12-2
- Explicitly enable grub2 hook; otherwise we pick up whatever
  the buildroot has, which is not what we want.

* Mon Nov 19 2012 Colin Walters <walters@verbum.org> - 2012.12-1
- Initial import; thanks to Michel Alexandre Salim for review
  https://bugzilla.redhat.com/show_bug.cgi?id=819951

